==> DynamicJasper-2.0.8-sources.jar: ar/com/fdvs/dj/domain/constants/HorizontalAlign.java <==
/*
 * Dynamic Jasper: A library for creating reports dynamically by specifying
 * columns, groups, styles, etc. at runtime. It also saves a lot of development
 * time in many cases! (http://sourceforge.net/projects/dynamicjasper)
 *
 * Copyright (C) 2008  FDV Solutions (http://www.fdvsolutions.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 *
 * License as published by the Free Software Foundation; either
 *
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 */

package ar.com.fdvs.dj.domain.constants;

public class HorizontalAlign {

	public static HorizontalAlign LEFT = new HorizontalAlign((byte)1);
	public static HorizontalAlign RIGHT = new HorizontalAlign((byte)3);
	public static HorizontalAlign CENTER = new HorizontalAlign((byte)2);
	public static HorizontalAlign JUSTIFY = new HorizontalAlign((byte)4);

	private final byte value;

	public byte getValue() {
		return value;
	}

	private HorizontalAlign(byte value){
		this.value = value;
	}

}

==> DynamicJasper-5.0.11-sources.jar: ar/com/fdvs/dj/domain/constants/HorizontalAlign.java <==
/*
 * DynamicJasper: A library for creating reports dynamically by specifying
 * columns, groups, styles, etc. at runtime. It also saves a lot of development
 * time in many cases! (http://sourceforge.net/projects/dynamicjasper)
 *
 * Copyright (C) 2008  FDV Solutions (http://www.fdvsolutions.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 *
 * License as published by the Free Software Foundation; either
 *
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 */

package ar.com.fdvs.dj.domain.constants;

public class HorizontalAlign  extends BaseDomainConstant {

	private static final long serialVersionUID = 1L;
	
	public static HorizontalAlign LEFT = new HorizontalAlign((byte)1);
	public static HorizontalAlign RIGHT = new HorizontalAlign((byte)3);
	public static HorizontalAlign CENTER = new HorizontalAlign((byte)2);
	public static HorizontalAlign JUSTIFY = new HorizontalAlign((byte)4);

	private final byte value;

	public byte getValue() {
		return value;
	}

	private HorizontalAlign(byte value){
		this.value = value;
	}

}
